@@ -1,9 +1,12 @@
+from __future__ import with_statement
+
 from flask import Flask, Response, abort, redirect, url_for, \
     jsonify, render_template
 
-from flaskext.testing import TestCase, TwillTestCase, \
+from flask_testing import TestCase, TwillTestCase, \
     ContextVariableDoesNotExist, Twill
 
+
 def create_app():
 
     app = Flask(__name__)
@@ -39,6 +42,7 @@ def create_app():
 
     return app
 
+
 class TestSetup(TestCase):
 
     def create_app(self):
@@ -46,9 +50,10 @@ class TestSetup(TestCase):
 
     def test_setup(self):
 
-        assert self.app
-        assert self.client
-        assert self._ctx
+        self.assertTrue(self.app is not None)
+        self.assertTrue(self.client is not None)
+        self.assertTrue(self._ctx is not None)
+
 
 class TestTwill(TestCase):
     
@@ -61,13 +66,13 @@ class TestTwill(TestCase):
         
         twill = Twill(self.app)
 
-        assert twill.host == '127.0.0.1'
-        assert twill.port == 5000
-        assert twill.browser
+        self.assertEqual(twill.host, "127.0.0.1")
+        self.assertEqual(twill.port, 5000)
+        self.assertTrue(twill.browser is not None)
 
     def test_make_twill_url(self):
         with Twill(self.app) as t:
-            assert t.url("/") == "http://127.0.0.1:5000/"
+            self.assertEqual(t.url("/"), "http://127.0.0.1:5000/")
 
 
 class TestClientUtils(TestCase):
@@ -75,44 +80,30 @@ class TestClientUtils(TestCase):
     def create_app(self):
         return create_app()
     
-    def test_getJSON(self):
-
+    def test_get_json(self):
         response = self.client.get("/ajax/")
-        assert response.json == dict(name="test")
+        self.assertEqual(response.json, dict(name="test"))
 
     def test_assert_200(self):
-
-        response = self.client.get("/")
-        self.assert200(response)
+        self.assert200(self.client.get("/"))
 
     def test_assert_404(self):
-
-        response = self.client.get("/oops/")
-        self.assert404(response)
+        self.assert404(self.client.get("/oops/"))
 
     def test_assert_403(self):
-
-        response = self.client.get("/forbidden/")
-        self.assert403(response)
+        self.assert403(self.client.get("/forbidden/"))
     
     def test_assert_401(self):
-
-        response = self.client.get("/unauthorized/")
-        self.assert401(response)
-
+        self.assert401(self.client.get("/unauthorized/"))
 
     def test_assert_405(self):
-
-        response = self.client.post("/")
-        self.assert405(response)
+        self.assert405(self.client.post("/"))
 
     def test_assert_redirects(self):
-
         response = self.client.get("/redirect/")
         self.assertRedirects(response, "/")
 
     def test_assert_template_used(self):
-
         try:
             response = self.client.get("/template/")
             self.assert_template_used("index.html")
@@ -120,7 +111,6 @@ class TestClientUtils(TestCase):
             pass
 
     def test_assert_template_not_used(self):
-
         response = self.client.get("/")
         try:
             self.assert_template_used("index.html")
@@ -131,15 +121,13 @@ class TestClientUtils(TestCase):
             pass
 
     def test_get_context_variable(self):
-
         try:
             response = self.client.get("/template/")
-            assert self.get_context_variable("name") == "test"
+            self.assertEqual(self.get_context_variable("name"), "test")
         except RuntimeError:
             pass
 
     def test_assert_context(self):
-
         try:
             response = self.client.get("/template/")
             self.assert_context("name", "test")
@@ -147,16 +135,16 @@ class TestClientUtils(TestCase):
             pass
 
     def test_assert_bad_context(self):
-
         try:
             response = self.client.get("/template/")
-            self.assertRaises(AssertionError, self.assert_context, "name", "foo")
-            self.assertRaises(AssertionError, self.assert_context, "foo", "foo")
+            self.assertRaises(AssertionError, self.assert_context,
+                              "name", "foo")
+            self.assertRaises(AssertionError, self.assert_context,
+                              "foo", "foo")
         except RuntimeError:
             pass
 
     def test_assert_get_context_variable_not_exists(self):
-
         try:
             response = self.client.get("/template/")
             self.assertRaises(ContextVariableDoesNotExist, 
@@ -173,15 +161,9 @@ class TestTwillDeprecated(TwillTestCase):
         return app
 
     def test_twill_setup(self):
-        
-        assert self.app
-        assert self.twill_host == '127.0.0.1'
-        assert self.twill_port == 5000
-        assert self.browser
+        self.assertEqual(self.twill_host, '127.0.0.1')
+        self.assertEqual(self.twill_port, 5000)
+        self.assertTrue(self.browser is not None)
 
     def test_make_twill_url(self):
-
-        assert self.make_twill_url("/") == \
-            "http://127.0.0.1:5000/"
-
-   
+        self.assertEqual(self.make_twill_url("/"), "http://127.0.0.1:5000/")
